@@ -14,8 +14,6 @@
 
 import abc
 
-import six
-
 
 # The following keys are used in the segment dictionaries passed via
 # the driver API.
@@ -33,8 +31,7 @@ BOUND_DRIVER = 'bound_driver'
 BOUND_SEGMENT = 'bound_segment'
 
 
-@six.add_metaclass(abc.ABCMeta)
-class MechanismDriver(object):
+class MechanismDriver(object, metaclass=abc.ABCMeta):
     """Define stable abstract interface for ML2 mechanism drivers.
 
     A mechanism driver is called on the creation, update, and deletion
@@ -447,9 +444,34 @@ class MechanismDriver(object):
         """
         return False
 
+    @staticmethod
+    def provider_network_attribute_updates_supported():
+        """Returns the provider network attributes that can be updated
 
-@six.add_metaclass(abc.ABCMeta)
-class _TypeDriverBase(object):
+        Possible values: neutron_lib.api.definitions.provider_net.ATTRIBUTES
+
+        :returns: (list) provider network attributes that can be updated in a
+                         live network using this driver.
+        """
+        return []
+
+    def supported_extensions(self, extensions):
+        """Return the mechanism driver supported extensions
+
+        By default this method will return the same provided set, without any
+        filtering. In case any particular mechanism driver needs to filter out
+        any specific extension or supports only a reduced set of extensions,
+        this method should be override.
+
+        :param extensions: set of extensions supported by the instance that
+                           created this mechanism driver.
+        :returns: a set of the extensions currently supported by this
+                  mechanism driver
+        """
+        return extensions
+
+
+class _TypeDriverBase(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_type(self):
@@ -498,19 +520,20 @@ class _TypeDriverBase(object):
         pass
 
     @abc.abstractmethod
-    def get_mtu(self, physical):
+    def get_mtu(self, physical, network=None):
         """Get driver's network MTU.
 
+        :param physical: name of the physical network
+        :param network: network parameters dictionary
         :returns: mtu maximum transmission unit
 
-        Returns the mtu for the network based on the config values and
-        the network type.
+        Returns the mtu for the network based on the config values,
+        the network type and the network attributes.
         """
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class TypeDriver(_TypeDriverBase):
+class TypeDriver(_TypeDriverBase, metaclass=abc.ABCMeta):
     """Define abstract interface for ML2 type drivers.
 
     ML2 type drivers each support a specific network_type for provider
@@ -534,11 +557,14 @@ class TypeDriver(_TypeDriverBase):
     """
 
     @abc.abstractmethod
-    def reserve_provider_segment(self, session, segment):
+    def reserve_provider_segment(self, session, segment, filters=None,
+                                 network=None):
         """Reserve resource associated with a provider network segment.
 
         :param session: database session
         :param segment: segment dictionary
+        :param filters: a dictionary that is used as search criteria
+        :param network: network parameters dictionary
         :returns: segment dictionary
 
         Called inside transaction context on session to reserve the
@@ -549,10 +575,12 @@ class TypeDriver(_TypeDriverBase):
         pass
 
     @abc.abstractmethod
-    def allocate_tenant_segment(self, session):
+    def allocate_tenant_segment(self, session, filters=None, network=None):
         """Allocate resource for a new tenant network segment.
 
         :param session: database session
+        :param filters: a dictionary that is used as search criteria
+        :param network: network parameters dictionary
         :returns: segment dictionary using keys defined above
 
         Called inside transaction context on session to allocate a new
@@ -579,8 +607,7 @@ class TypeDriver(_TypeDriverBase):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ML2TypeDriver(_TypeDriverBase):
+class ML2TypeDriver(_TypeDriverBase, metaclass=abc.ABCMeta):
     """Define abstract interface for ML2 type drivers.
 
     ML2 type drivers each support a specific network_type for provider
@@ -604,11 +631,14 @@ class ML2TypeDriver(_TypeDriverBase):
     """
 
     @abc.abstractmethod
-    def reserve_provider_segment(self, context, segment):
+    def reserve_provider_segment(self, context, segment, filters=None,
+                                 network=None):
         """Reserve resource associated with a provider network segment.
 
         :param context: instance of neutron context with DB session
         :param segment: segment dictionary
+        :param filters: a dictionary that is used as search criteria
+        :param network: network parameters dictionary
         :returns: segment dictionary
 
         Called inside transaction context on session to reserve the
@@ -619,10 +649,12 @@ class ML2TypeDriver(_TypeDriverBase):
         pass
 
     @abc.abstractmethod
-    def allocate_tenant_segment(self, context):
+    def allocate_tenant_segment(self, context, filters=None, network=None):
         """Allocate resource for a new tenant network segment.
 
         :param context: instance of neutron context with DB session
+        :param filters: a dictionary that is used as search criteria
+        :param network: network parameters dictionary
         :returns: segment dictionary using keys defined above
 
         Called inside transaction context on session to allocate a new
@@ -648,9 +680,28 @@ class ML2TypeDriver(_TypeDriverBase):
         """
         pass
 
+    @abc.abstractmethod
+    def initialize_network_segment_range_support(self):
+        """Perform driver network segment range initialization.
 
-@six.add_metaclass(abc.ABCMeta)
-class NetworkContext(object):
+        Called during the initialization of the ``network-segment-range``
+        service plugin if enabled, after all drivers have been loaded and the
+        database has been initialized. This reloads the `default`
+        network segment ranges when Neutron server starts/restarts.
+        """
+        pass
+
+    @abc.abstractmethod
+    def update_network_segment_range_allocations(self):
+        """Update driver network segment range allocations.
+
+        This syncs the driver segment allocations when network segment ranges
+        have been created, updated or deleted.
+        """
+        pass
+
+
+class NetworkContext(object, metaclass=abc.ABCMeta):
     """Context passed to MechanismDrivers for changes to network resources.
 
     A NetworkContext instance wraps a network resource. It provides
@@ -687,8 +738,7 @@ class NetworkContext(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SubnetContext(object):
+class SubnetContext(object, metaclass=abc.ABCMeta):
     """Context passed to MechanismDrivers for changes to subnet resources.
 
     A SubnetContext instance wraps a subnet resource. It provides
@@ -720,8 +770,7 @@ class SubnetContext(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class PortContext(object):
+class PortContext(object, metaclass=abc.ABCMeta):
     """Context passed to MechanismDrivers for changes to port resources.
 
     A PortContext instance wraps a port resource. It provides helper
@@ -1038,8 +1087,7 @@ class PortContext(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ExtensionDriver(object):
+class ExtensionDriver(object, metaclass=abc.ABCMeta):
     """Define stable abstract interface for ML2 extension drivers.
 
     An extension driver extends the core resources implemented by the
