@@ -10,7 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
+from oslo_config import cfg
 from oslo_context import context as oslo_context
 from testtools import matchers
 
@@ -151,6 +153,16 @@ class TestNeutronContext(_base.BaseTestCase):
         elevated2_ctx = elevated_ctx.elevated()
         self.assertTrue(elevated2_ctx.is_admin)
 
+    def test_neutron_context_elevated_system_scope_for_new_policies(self):
+        cfg.CONF.set_override(
+            'enforce_new_defaults', True, group='oslo_policy')
+        ctx = context.Context('user_id', 'tenant_id')
+        self.assertFalse(ctx.is_admin)
+        self.assertNotEqual('all', ctx.system_scope)
+        elevated_ctx = ctx.elevated()
+        self.assertTrue(elevated_ctx.is_admin)
+        self.assertEqual('all', elevated_ctx.system_scope)
+
     def test_neutron_context_overwrite(self):
         ctx1 = context.Context('user_id', 'tenant_id')
         self.assertEqual(ctx1.request_id,
@@ -213,3 +225,14 @@ class TestNeutronContext(_base.BaseTestCase):
         session1 = ctx.session
         session2 = ctx.session
         self.assertIs(session1, session2)
+
+    def test_add_get_remove_constraint(self):
+        ctx = context.Context('user_id', 'tenant_id')
+        self.assertIsNone(ctx.get_transaction_constraint())
+        ctx.set_transaction_constraint('networks', 'net_id', 44)
+        constraint = ctx.get_transaction_constraint()
+        self.assertEqual(44, constraint.if_revision_match)
+        self.assertEqual('networks', constraint.resource)
+        self.assertEqual('net_id', constraint.resource_id)
+        ctx.clear_transaction_constraint()
+        self.assertIsNone(ctx.get_transaction_constraint())
